pub struct PreparedAnimation { /* private fields */ }Expand description
One-shot reservation of a prepared animation on its controller’s worker. Dropping it before start cancels without moving desktop icons.
Implementations
Sourceimpl PreparedAnimation
impl PreparedAnimation
Sourcepub fn start(self) -> Result<AnimationHandle, DesktopError>
pub fn start(self) -> Result<AnimationHandle, DesktopError>
Consume the reservation and start its visual clock on the worker.
pub fn open_timeline(self) -> Result<TimelineSession, DesktopError>