pub struct DesktopInfo {
pub bounds: Rect,
pub monitors: Vec<MonitorInfo>,
pub grids: Vec<IconGrid>,
}Expand description
A read-only snapshot in physical virtual-screen pixels. Gaps between monitors
are included in bounds, but are never usable grid cells.
Fields
bounds: Rectmonitors: Vec<MonitorInfo>grids: Vec<IconGrid>Trait Implementations
Sourceimpl Clone for DesktopInfo
impl Clone for DesktopInfo
Sourcefn clone(&self) -> DesktopInfo
fn clone(&self) -> DesktopInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DesktopInfo
impl Debug for DesktopInfo
Sourceimpl PartialEq for DesktopInfo
impl PartialEq for DesktopInfo
Sourcefn eq(&self, other: &DesktopInfo) -> bool
fn eq(&self, other: &DesktopInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DesktopInfo