pub struct IconBitmap {
pub width: u32,
pub height: u32,
pub stride: u32,
pub pixels: Vec<u8>,
}Expand description
Premultiplied BGRA icon bitmap the renderer can upload directly to a GPU texture / Direct2D bitmap.
Bytes are pixels[y * stride + x * 4] = [B, G, R, A] with premultiplied
alpha. stride is in bytes and must equal width * 4 (no padding).
Fields
width: u32height: u32stride: u32Row stride in bytes (= width * 4).
pixels: Vec<u8>Trait Implementations
Sourceimpl Clone for IconBitmap
impl Clone for IconBitmap
Sourcefn clone(&self) -> IconBitmap
fn clone(&self) -> IconBitmap
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IconBitmap
impl Debug for IconBitmap
Sourceimpl PartialEq for IconBitmap
impl PartialEq for IconBitmap
Sourcefn eq(&self, other: &IconBitmap) -> bool
fn eq(&self, other: &IconBitmap) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for IconBitmap